SystemOrganization addCategory: #'Zinc-WebSocket-Tests'!

TestCase subclass: #ZnWebSocketFrameTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-WebSocket-Tests'!

!ZnWebSocketFrameTests commentStamp: '<historical>' prior: 0!
I am ZnWebSocketFrameTests.
!

!ZnWebSocketFrameTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/22/2012 10:46'!
testReading256ByteSingleFrameUnmaskedBinaryMessage
	"Fifth example from RFC 6455 section 5.7"

	| payload bytes frame |
	payload := ZnWebSocketUtils randomByteArrayOfSize: 256.
	bytes := (ByteArray readHexFrom: '827e0100'), payload.
	frame := ZnWebSocketFrame readFrom: bytes readStream.
	self assert: frame isBinary.
	self deny: frame isMasked.
	self assert: frame isFinal.
	self assert: frame size equals: 256.
	self assert: frame body equals: payload.
! !

!ZnWebSocketFrameTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/22/2012 10:46'!
testReading256KiBSingleFrameUnmaskedBinaryMessage
	"Fifth example from RFC 6455 section 5.7"

	| payload bytes frame |
	payload := ZnWebSocketUtils randomByteArrayOfSize: (2 raisedTo: 16).
	bytes := (ByteArray readHexFrom: '827f0000000000010000'), payload.
	frame := ZnWebSocketFrame readFrom: bytes readStream.
	self assert: frame isBinary.
	self deny: frame isMasked.
	self assert: frame isFinal.
	self assert: frame size equals: (2 raisedTo: 16).
	self assert: frame body equals: payload.
! !

!ZnWebSocketFrameTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/22/2012 10:29'!
testReadingFragmentedUnmaskedTextMessage
	"Third example from RFC 6455 section 5.7"

	| bytes stream frame |
	bytes := ByteArray readHexFrom: '010348656c80026c6f'.
	stream := bytes readStream.
	frame := ZnWebSocketFrame readFrom: stream.
	self assert: frame isText.
	self deny: frame isMasked.
	self deny: frame isFinal.
	self assert: frame text equals: 'Hel'.
	self deny: stream atEnd.
	frame := ZnWebSocketFrame readFrom: stream.
	self assert: frame isContinuation.
	self deny: frame isMasked.
	self assert: frame isFinal.
	self assert: frame text equals: 'lo'.
	self assert: stream atEnd.
	! !

!ZnWebSocketFrameTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/22/2012 10:32'!
testReadingPing
	"Fourth example from RFC 6455 section 5.7"

	| bytes frame |
	bytes := ByteArray readHexFrom: '890548656c6c6f'.
	frame := ZnWebSocketFrame readFrom: bytes readStream.
	self assert: frame isPing.
	self deny: frame isMasked.
	self assert: frame isFinal.
	self assert: frame text equals: 'Hello'.
! !

!ZnWebSocketFrameTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/22/2012 10:32'!
testReadingPong
	"Fourth example from RFC 6455 section 5.7"

	| bytes frame |
	bytes := ByteArray readHexFrom: '8a8537fa213d7f9f4d5158'.
	frame := ZnWebSocketFrame readFrom: bytes readStream.
	self assert: frame isPong.
	self assert: frame isMasked.
	self assert: frame isFinal.
	self assert: frame text equals: 'Hello'.
! !

!ZnWebSocketFrameTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/22/2012 10:12'!
testReadingSingleFrameMaskedTextMessage
	"Second example from RFC 6455 section 5.7"
	
	| bytes frame |
	bytes := ByteArray readHexFrom: '818537fa213d7f9f4d5158'.
	frame := ZnWebSocketFrame readFrom: bytes readStream.
	self assert: frame isText.
	self assert: frame isMasked.
	self assert: frame isFinal.
	self assert: frame contents equals: 'Hello'! !

!ZnWebSocketFrameTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/22/2012 10:12'!
testReadingSingleFrameUnmaskedTextMessage
	"First example from RFC 6455 section 5.7"

	| bytes frame |
	bytes := ByteArray readHexFrom: '810548656c6c6f'.
	frame := ZnWebSocketFrame readFrom: bytes readStream.
	self assert: frame isText.
	self deny: frame isMasked.
	self assert: frame isFinal.
	self assert: frame contents equals: 'Hello'! !

TestCase subclass: #ZnWebSocketTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-WebSocket-Tests'!

!ZnWebSocketTests commentStamp: '<historical>' prior: 0!
I am ZnWebSocketTests.!

!ZnWebSocketTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/21/2012 22:38'!
testEchoLocally
	| webSocket message |
	ZnServer startDefaultOn: 1701.
	ZnServer default logToTranscript.
	ZnServer default delegate
		map: 'ws-test' 
		to: [ :request | ZnResponse ok: (ZnEntity html: ZnWebSocketDelegate wsTestHtml) ];
		map: 'ws-test-local' 
		to: [ :request | ZnResponse ok: (ZnEntity html: ZnWebSocketDelegate wsTestLocalHtml) ];
		map: 'ws-echo'
		to: [ :request | ZnWebSocketDelegate new handleRequest: request ].
	webSocket := ZnWebSocket to: 'ws://localhost:1701/ws-echo'.
	message := 'Greetings from Pharo Smalltalk @ ', TimeStamp now printString.
	webSocket sendMessage: message.
	self assert: webSocket readMessage equals: message.
	webSocket close.
	ZnServer stopDefault.! !

!ZnWebSocketTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/22/2012 10:04'!
testEchoSecureWebSocketsDotOrg
	| webSocket message |
	webSocket := ZnWebSocket to: 'wss://echo.websocket.org'.
	message := 'Greetings from Pharo Smalltalk @ ', TimeStamp now printString.
	webSocket sendMessage: message.
	self assert: webSocket readMessage equals: message.
	webSocket close.! !

!ZnWebSocketTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/21/2012 22:36'!
testEchoWebSocketsDotOrg
	| webSocket message |
	webSocket := ZnWebSocket to: 'ws://echo.websocket.org'.
	message := 'Greetings from Pharo Smalltalk @ ', TimeStamp now printString.
	webSocket sendMessage: message.
	self assert: webSocket readMessage equals: message.
	webSocket close.! !
